summaryrefslogtreecommitdiffstats
path: root/kword/KWFrameSet.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /kword/KWFrameSet.h
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kword/KWFrameSet.h')
-rw-r--r--kword/KWFrameSet.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kword/KWFrameSet.h b/kword/KWFrameSet.h
index 7218abe7..67cad0da 100644
--- a/kword/KWFrameSet.h
+++ b/kword/KWFrameSet.h
@@ -199,7 +199,7 @@ public:
* The way this "onlyChanged/resetChanged" works is: when something changes,
* all views are asked to redraw themselves with onlyChanged=true.
* But all views except the last one shouldn't reset the changed flag to false,
* otherwise the other views wouldn't tqrepaint anything.
* So resetChanged is called with "false" for all views except the last one,
* and with "true" for the last one, so that it resets the flag.
*
@@ -310,9 +310,9 @@ public:
/** Allows to detect that updateFrames() hasn't been called yet (e.g. on loading) */
bool hasFramesInPageArray() const { return !m_framesInPage.isEmpty(); }
- /** retqlayout text in frames, so that it flows correctly around other frames */
- virtual void tqlayout() {}
- virtual void tqinvalidate() {}
+ /** relayout text in frames, so that it flows correctly around other frames */
+ virtual void layout() {}
+ virtual void invalidate() {}
/// save to XML - when saving
virtual TQDomElement save( TQDomElement &parentElem, bool saveFrames = true ) = 0;
@@ -359,11 +359,11 @@ public:
* Make this frameset anchored, with the anchor at @p paragId,@p index in the text frameset @p textfs.
* Also used during OASIS loading (placeHolderExists=true)
*/
- void setAnchored( KWTextFrameSet* textfs, KoTextParag* parag, int index, bool placeHolderExists = false, bool tqrepaint = true );
+ void setAnchored( KWTextFrameSet* textfs, KoTextParag* parag, int index, bool placeHolderExists = false, bool repaint = true );
/** Make this frameset floating, with the anchor at @p paragId,@p index in the text frameset @p textfs.
* \deprecated
*/
- void setAnchored( KWTextFrameSet* textfs, int paragId, int index, bool placeHolderExists = false, bool tqrepaint = true );
+ void setAnchored( KWTextFrameSet* textfs, int paragId, int index, bool placeHolderExists = false, bool repaint = true );
/** Note that this frameset has been made floating already, and store anchor position */
void setAnchored( KWTextFrameSet* textfs );
/// Make this frameset fixed, i.e. not anchored
@@ -455,7 +455,7 @@ public:
signals:
/// Emitted when something has changed in this frameset,
/// so that all views tqrepaint it. KWDocument connects to it,
/// and KWCanvas connects to KWDocument.
void repaintChanged( KWFrameSet * frameset );
@@ -478,7 +478,7 @@ protected:
void deleteAnchor( KWAnchor * anchor );
virtual void deleteAnchors();
- virtual void createAnchors( KoTextParag * parag, int index, bool placeHolderExists = false, bool tqrepaint = true );
+ virtual void createAnchors( KoTextParag * parag, int index, bool placeHolderExists = false, bool repaint = true );
KWDocument *m_doc; // Document
@@ -199,7 +199,7 @@ public:
* all views are asked to redraw themselves with onlyChanged=true.
* But all views except the last one shouldn't reset the changed flag to false,
- * otherwise the other views wouldn't tqrepaint anything.
+ * otherwise the other views wouldn't repaint anything.
* So resetChanged is called with "false" for all views except the last one,
* and with "true" for the last one, so that it resets the flag.
@@ -455,7 +455,7 @@ public:
signals:
/// Emitted when something has changed in this frameset,
- /// so that all views tqrepaint it. KWDocument connects to it,
+ /// so that all views repaint it. KWDocument connects to it,
/// and KWCanvas connects to KWDocument.
void repaintChanged( KWFrameSet * frameset );